<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Monitor Sistem</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Monitor Sistem adalah alat untuk memantau beban sistem secara waktu nyata, melihat dan mengontrol proses dan layanan yang berjalan di sistem Anda.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Sembunyikan detail</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Baca</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Tulis</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 detik</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 hari %2 jam %3 menit</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Pemanfaatan</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Frekuensi sekarang</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekuensi</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Vendor</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Soket</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Prosesor Logis</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualisasi</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i cache</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d cache</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 cache</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 cache</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Muat rata-rata</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Deskriptor berkas</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nama hos</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Tipe Sistem Operasi</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 detik</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Tidak ada hasil pencarian</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detail</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detail</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktif</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>sedang memuat kembali</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>tidak aktif</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>gagal</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>mengaktifkan</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>menonaktifkan</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>tidak ditemukan</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>setelan buruk</translation>
    </message>
    <message>
        <source>error</source>
        <translation>galat</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>tergabung</translation>
    </message>
    <message>
        <source>masked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>loaded</source>
        <translation>dibuat</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>diaktifkan</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>dinonaktifkan</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statik</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>sementara</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>tidak langsung</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>masked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>generated</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>mati</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>berjalan</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>exited</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>reload</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>gagal</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-restart</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Digunakan</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tersedia</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Dibagikan</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buffers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cached swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Nonaktif</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Kotor</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Dipetakan</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Total swap</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Bebaskan swap</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Kecepatan membaca</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Kecepatan menulis</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapasitas</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Sektor dibaca</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Reads/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Sektor read/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Baca merged/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Sektor ditulis</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Writes merged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Writes/s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Sektor written/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Writes merged/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilkan pemintas</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Mengakhiri proses ini dapat menyebabkan kehilangan data.
Anda yakin untuk melanjutkan?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Akhiri proses</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Mengakhiri proses ini dengan paksa dapat menyebabkan kehilangan data.
Anda yakin akan melanjutkannya?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batalkan</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Paksa berhenti</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Akhiri</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Ukuran</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Alamat IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Netmask:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Scope:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Tipe koneksi</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Kualitas tautan</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Kekuatan sinyal</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Level kebisingan</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Lebar pita</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX packets</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX bytes</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX errors</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX dropped</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX overruns</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX frame</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX packets</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX bytes</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX errors</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX overruns</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX dropped</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Baris perintah</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Waktu mulai</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klik aplikasi yang ingin Anda hentikan</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Memori</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Menerima</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memori</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Tidak diaktifkan</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Unggah</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Jaringan</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Total diterima</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Total dikirim</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Kirim</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diska</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Sangat tinggi</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Tinggi</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Rendah</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Sangat rendah</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Kustom</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Tidak valid</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Galat: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Gagal mengubah prioritas proses</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplikasi</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Proses saya</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Semua proses</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Gagal menjeda proses</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Gagal melanjutkan proses</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Gagal mematikan proses</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Galat tidak diketahui</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Gagal mengirim sinyal ke proses</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Gagal mengakhiri proses</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplikasi dan %2 proses berjalan)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Tak ada respons</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Baki</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Lihat lokasi perintah</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Properti</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Akhiri proses</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Lanjutkan proses</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Matikan proses</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Ubah prioritas</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Tangguhkan proses</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Prioritas kustom</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batalkan</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Ubah</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memori</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Unggah</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritas</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Protection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Gagal menyetel jenis layanan startup</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Galat: Gagal menyetel tipe layanan startup karena subproses macet.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batalkan</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Segarkan</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Setop</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Mulai ulang</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Tipe startup</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>State</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description</source>
        <translation>Deskripsi</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Tipe Startup</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Expand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Compact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Services</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
